pitchtools.PitchObjectSegment
=============================

.. inheritance-diagram:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.count

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.index

    Inherited from :py:class:`__builtin__.tuple`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__add__

    Inherited from :py:class:`pitchtools.ObjectSegment <abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment>`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__contains__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__eq__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__ge__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__getitem__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__getslice__

    Inherited from :py:class:`pitchtools.ObjectSegment <abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment>`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__gt__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__hash__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__iter__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__le__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__len__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__lt__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__mul__

    Inherited from :py:class:`pitchtools.ObjectSegment <abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment>`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__ne__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__repr__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.PitchObjectSegment.PitchObjectSegment.PitchObjectSegment.__rmul__

    Inherited from :py:class:`pitchtools.ObjectSegment <abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment>`
